@@ -6,6 +6,9 @@ use chrono::prelude::*;
 use clap::{crate_version, load_yaml, App};
 use std::collections::HashMap;
 
+#[cfg(test)]
+mod tests;
+
 // continuously inject weather into incoming json lines from i3status and pass through
 fn main() {
     // fetch arguments
@@ -37,7 +40,7 @@ fn main() {
         // update current weather info if there is an update available
         match openweathermap::update(receiver) {
             Some(response) => match response {
-                Ok(w) => current = make_string(format, &w, units),
+                Ok(w) => current = make_string(format, &w, &units),
                 Err(e) => current = e,
             },
             None => (),
